@@ -1,6 +1,7 @@
 extern crate glob;
 
 use glob::glob;
+use std::collections::HashSet;
 use std::env;
 use std::fs;
 use std::io::{self, BufRead, Write};
@@ -15,9 +16,8 @@ fn get_crate_dir() -> io::Result<path::PathBuf> {
 }
 
 fn get_out_dir() -> io::Result<path::PathBuf> {
-    Ok(path::PathBuf::from(env::var("OUT_DIR").map_err(|_| {
-        io::Error::new(io::ErrorKind::Other, "no OUT_DIR")
-    })?))
+    Ok(path::PathBuf::from(env::var("OUT_DIR")
+        .map_err(|_| io::Error::new(io::ErrorKind::Other, "no OUT_DIR"))?))
 }
 
 fn get_crate_test_path(file_name: &str) -> io::Result<path::PathBuf> {
@@ -60,7 +60,11 @@ use std::io::Read;
 
     let mut in_dir = get_crate_dir()?;
     in_dir.push("in");
-    assert!(in_dir.is_dir());
+    if !in_dir.is_dir() {
+        // We are in `cargo publish` and the `in/` directory isn't included in
+        // the distributed package.
+        return Ok(());
+    }
 
     let entries = fs::read_dir(in_dir)?;
 
@@ -93,11 +97,6 @@ fn test_afl_seed_{}() {{
     Ok(())
 }
 
-// Ratcheting number that is increased as more libiberty tests start
-// passing. Once they are all passing, this can be removed and we can enable all
-// of them by default.
-const LIBIBERTY_TEST_THRESHOLD: usize = 83;
-
 /// Read `tests/libiberty-demangle-expected`, parse its input mangled symbols,
 /// and expected output demangled symbols, and generate test cases for them.
 ///
@@ -109,6 +108,14 @@ const LIBIBERTY_TEST_THRESHOLD: usize = 83;
 fn generate_compatibility_tests_from_libiberty() -> io::Result<()> {
     println!("cargo:rerun-if-changed=tests/libiberty-demangle-expected");
 
+    let mut tests_dir = get_crate_dir()?;
+    tests_dir.push("tests");
+    if !tests_dir.is_dir() {
+        // We are in `cargo publish` and the `in/` directory isn't included in
+        // the distributed package.
+        return Ok(());
+    }
+
     let test_path = get_test_path("libiberty.rs")?;
     let _ = fs::remove_file(&test_path);
     let mut test_file = fs::File::create(test_path)?;
@@ -122,6 +129,31 @@ use std::fmt::Write;
 "
     )?;
 
+    // The set of libiberty tests that pass. This should only ever grow!
+    let libiberty_passing_tests = {
+        let mut s: HashSet<_> = (0..86).collect();
+        s.extend(87..89);
+        s.extend(92..93);
+        s.extend(94..105);
+        s.extend(107..108);
+        s.extend(116..118);
+        s.extend(122..124);
+        s.extend(128..131);
+        s.extend(133..134);
+        s.extend(141..143);
+        s.extend(151..152);
+        s.extend(153..154);
+        s.extend(158..168);
+        s.extend(169..170);
+        s.extend(179..180);
+        s.extend(181..182);
+        s.extend(185..186);
+        s.extend(188..189);
+        s.extend(201..202);
+        s.extend(203..204);
+        s
+    };
+
     let libiberty_tests = get_crate_test_path("libiberty-demangle-expected")?;
     let libiberty_tests = fs::File::open(libiberty_tests)?;
     let libiberty_tests = io::BufReader::new(libiberty_tests);
@@ -178,14 +210,14 @@ use std::fmt::Write;
         }
 
         // Skip tests for unsupported languages or options.
-        if options.find("--format=gnu-v3").is_none() || options.find("--is-v3-ctor").is_some() ||
-            options.find("--is-v3-dtor").is_some() ||
-            options.find("--ret-postfix").is_some()
+        if options.find("--format=gnu-v3").is_none() || options.find("--is-v3-ctor").is_some()
+            || options.find("--is-v3-dtor").is_some()
+            || options.find("--ret-postfix").is_some()
         {
             continue;
         }
 
-        let cfg = if n <= LIBIBERTY_TEST_THRESHOLD {
+        let cfg = if libiberty_passing_tests.contains(&n) {
             ""
         } else {
             r###"#[cfg(feature = "run_libiberty_tests")]"###
@@ -264,11 +296,9 @@ fn test_libiberty_demangle_{}_() {{
 fn main() {
     println!("cargo:rerun-if-changed=build.rs");
 
-    generate_sanity_tests_from_afl_seeds().expect(
-        "should generate sanity tests from AFL.rs seed test cases",
-    );
+    generate_sanity_tests_from_afl_seeds()
+        .expect("should generate sanity tests from AFL.rs seed test cases");
 
-    generate_compatibility_tests_from_libiberty().expect(
-        "should generate compatibility tests from tests/libiberty-demangle-expected",
-    );
+    generate_compatibility_tests_from_libiberty()
+        .expect("should generate compatibility tests from tests/libiberty-demangle-expected");
 }
