@@ -24,6 +24,10 @@ pub enum Error {
     /// a context without function args.
     BadFunctionArgReference,
 
+    /// Found a reference to a leaf name in a context where there is no current
+    /// leaf name.
+    BadLeafNameReference,
+
     /// An overflow or underflow would occur when parsing an integer in a
     /// mangled symbol.
     Overflow,
@@ -47,30 +51,29 @@ impl fmt::Display for Error {
         match *self {
             Error::UnexpectedEnd => write!(f, "mangled symbol ends abruptly"),
             Error::UnexpectedText => write!(f, "mangled symbol is not well-formed"),
-            Error::BadBackReference => {
-                write!(
-                    f,
-                    "back reference that is out-of-bounds of the substitution table"
-                )
-            }
-            Error::BadTemplateArgReference => {
-                write!(
-                    f,
-                    "reference to a template arg that is either out-of-bounds, or in a context without template args"
-                )
-            }
-            Error::BadFunctionArgReference => {
-                write!(
-                    f,
-                    "reference to a function arg that is either out-of-bounds, or in a context without function args"
-                )
-            }
-            Error::Overflow => {
-                write!(
-                    f,
-                    "an overflow or underflow would occur when parsing an integer in a mangled symbol"
-                )
-            }
+            Error::BadBackReference => write!(
+                f,
+                "back reference that is out-of-bounds of the substitution table"
+            ),
+            Error::BadTemplateArgReference => write!(
+                f,
+                "reference to a template arg that is either out-of-bounds, or in a context \
+                 without template args"
+            ),
+            Error::BadFunctionArgReference => write!(
+                f,
+                "reference to a function arg that is either out-of-bounds, or in a context \
+                 without function args"
+            ),
+            Error::BadLeafNameReference => write!(
+                f,
+                "reference to a leaf name in a context where there is no current leaf name"
+            ),
+            Error::Overflow => write!(
+                f,
+                "an overflow or underflow would occur when parsing an integer in a mangled \
+                 symbol"
+            ),
             Error::TooMuchRecursion => {
                 write!(f, "encountered too much recursion when demangling symbol")
             }
@@ -87,10 +90,15 @@ impl error::Error for Error {
                 "back reference that is out-of-bounds of the substitution table"
             }
             Error::BadTemplateArgReference => {
-                "reference to a template arg that is either out-of-bounds, or in a context without template args"
+                "reference to a template arg that is either out-of-bounds, or in a context \
+                 without template args"
             }
             Error::BadFunctionArgReference => {
-                "reference to a function arg that is either out-of-bounds, or in a context without function args"
+                "reference to a function arg that is either out-of-bounds, or in a context \
+                 without function args"
+            }
+            Error::BadLeafNameReference => {
+                "reference to a leaf name in a context where there is no current leaf name"
             }
             Error::Overflow => {
                 "an overflow or underflow would occur when parsing an integer in a mangled symbol"
